==> igniteui-react-charts-16.6.8.tgz: package/ES5/igr-scatter-polyline-series.js <==
import * as tslib_1 from "tslib";
import { Style } from "igniteui-react-core/ES5/igr-style";
import { IgrShapeSeriesBase } from "./igr-shape-series-base";
import { ScatterPolylineSeries } from "./ScatterPolylineSeries";
/**
 * Series class used for displaying multiple polylines for datasources which contain multiple lists of points.
*/
var IgrScatterPolylineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrScatterPolylineSeries, _super);
    function IgrScatterPolylineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrScatterPolylineSeries.prototype.createImplementation = function () {
        return new ScatterPolylineSeries();
    };
    Object.defineProperty(IgrScatterPolylineSeries.prototype, "i", {
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrScatterPolylineSeries.prototype, "shapeStyleSelector", {
        /**
         * The StyleSelector which is used to select a style for each Shape.
        */
        get: function () {
            return this.i.m4;
        },
        set: function (v) {
            this.i.m4 = v;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrScatterPolylineSeries.prototype, "shapeStyle", {
        /**
         * The default style to apply to all Shapes in the series.
        */
        get: function () {
            if (this.i.m9 == null) {
                return null;
            }
            if (!this.i.m9.externalObject) {
                var e = new Style();
                e._implementation = this.i.m9;
                this.i.m9.externalObject = e;
            }
            return this.i.m9.externalObject;
        },
        set: function (v) {
            v == null ? this.i.m9 = null : this.i.m9 = v.i;
        },
        enumerable: true,
        configurable: true
    });
    return IgrScatterPolylineSeries;
}(IgrShapeSeriesBase));
export { IgrScatterPolylineSeries };

==> igniteui-react-charts-16.11.1.tgz: package/ES5/igr-scatter-polyline-series.js <==
import * as tslib_1 from "tslib";
import { Style } from "igniteui-react-core/ES5/igr-style";
import { IgrShapeSeriesBase } from "./igr-shape-series-base";
import { ScatterPolylineSeries } from "./ScatterPolylineSeries";
/**
 * Series class used for displaying multiple polylines for datasources which contain multiple lists of points.
*/
var IgrScatterPolylineSeries = /** @class */ (function (_super) {
    tslib_1.__extends(IgrScatterPolylineSeries, _super);
    function IgrScatterPolylineSeries(props) {
        return _super.call(this, props) || this;
    }
    IgrScatterPolylineSeries.prototype.createImplementation = function () {
        return new ScatterPolylineSeries();
    };
    Object.defineProperty(IgrScatterPolylineSeries.prototype, "i", {
        /**
                                     * @hidden
                                     */
        get: function () {
            return this._implementation;
        },
        enumerable: true,
        configurable: true
    });
    Object.defineProperty(IgrScatterPolylineSeries.prototype, "shapeStyle", {
        /**
         * The default style to apply to all Shapes in the series.
        */
        get: function () {
            if (this.i.ng == null) {
                return null;
            }
            if (!this.i.ng.externalObject) {
                var e = new Style();
                e._implementation = this.i.ng;
                this.i.ng.externalObject = e;
            }
            return this.i.ng.externalObject;
        },
        set: function (v) {
            v == null ? this.i.ng = null : this.i.ng = v.i;
        },
        enumerable: true,
        configurable: true
    });
    return IgrScatterPolylineSeries;
}(IgrShapeSeriesBase));
export { IgrScatterPolylineSeries };
